=============
Bilby example
=============

``nessai`` can be used like any of the other samplers in ``bilby`` and the full range of settings are available. The following example mirrors the :doc:`Gaussian example<gaussian-example>` but using ``bilby``.

Code
====

.. literalinclude:: ../examples/bilby_example.py
    :language: python
